@@ -211,12 +211,12 @@
 #' @section Predictions and contrasts at meaningful values (data grids):
 #'
 #' To define representative values for focal predictors (specified in `by`,
-#' `contrast`, and `trend`), you can use several methods. These values are
+#' `contrast`, and `slope`), you can use several methods. These values are
 #' internally generated by `insight::get_datagrid()`, so consult its
 #' documentation for more details.
 #'
 #' * You can directly specify values as strings or lists for `by`, `contrast`,
-#'   and `trend`.
+#'   and `slope`.
 #'   * For numeric focal predictors, use examples like `by = "gear = c(4, 8)"`,
 #'     `by = list(gear = c(4, 8))` or `by = "gear = 5:10"`
 #'   * For factor or character predictors, use `by = "Species = c('setosa', 'virginica')"`
@@ -238,7 +238,8 @@
 #'   integer variables as numerics (and possibly produce fractions).
 #'
 #' See also [this vignette](https://easystats.github.io/modelbased/articles/visualisation_matrix.html)
-#' for some examples.
+#' for some examples, and [`insight::get_datagrid()`] to learn more about how to
+#' create data grids for predictors of interest.
 #'
 #' @section Predictions on different scales:
 #'
@@ -465,7 +466,12 @@ estimate_means <- function(
   }
 
   # sanity check - did method return standard errors?
-  .check_standard_errors(out = means, model = model, verbose = verbose)
+  .check_standard_errors(
+    out = means,
+    by = attributes(means)$by,
+    model = model,
+    verbose = verbose
+  )
 
   # restore attributes later
   info <- attributes(estimated)
