@@ -172,21 +172,22 @@
     "negbin", "negbin", "ols", "oohbchoice", "oohbchoice", "orm",
     "orm", "orm", "ordinal_weightit", "ordinal_weightit", "ordinal_weightit",
     "ordinal_weightit", "ordinal_weightit", "polr", "rendo.base",
-    "rendo.base", "rlm", "selection", "selection", "selection", "speedlm",
-    "speedglm", "speedglm", "stanreg", "stanreg", "survreg", "survreg",
-    "survreg", "svyglm", "svyglm", "svyolr", "tobit", "tobit", "tobit1",
-    "tobit1", "tobit1", "zeroinfl", "zeroinfl", "zeroinfl", "zeroinfl"
+    "rendo.base", "rlm", "selection", "selection", "selection", "selection",
+    "speedlm", "speedglm", "speedglm", "stanreg", "stanreg", "survreg",
+    "survreg", "survreg", "svyglm", "svyglm", "svyolr", "tobit",
+    "tobit", "tobit1", "tobit1", "tobit1", "zeroinfl", "zeroinfl",
+    "zeroinfl", "zeroinfl"
   ),
   type = c(
-    "response", "link", "ev", "ppd", "response", "link",
-    "precision", "quantile", "variance", "response", "link", "probs",
-    "response", "link", "response", "link", "prediction", "average",
-    "probs", "class", "prob", "cum.prob", "linear.predictor", "expected",
-    "lp", "risk", "survival", "survival", "expected", "lp", "risk",
-    "survival", "expected", "lp", "risk", "response", "location",
-    "scale", "density", "pr", "xb", "location", "cumprob", "scale",
-    "density", "pr", "xb", "survival", "response", "mean", "link",
-    "lp", "linear", "rmst", "hazard", "cumhaz", "invlink(link)",
+    "response", "link", "ev", "ppd",
+    "response", "link", "precision", "quantile", "variance", "response",
+    "link", "probs", "response", "link", "response", "link", "prediction",
+    "average", "probs", "class", "prob", "cum.prob", "linear.predictor",
+    "expected", "lp", "risk", "survival", "survival", "expected",
+    "lp", "risk", "survival", "expected", "lp", "risk", "response",
+    "location", "scale", "density", "pr", "xb", "location", "cumprob",
+    "scale", "density", "pr", "xb", "survival", "response", "mean",
+    "link", "lp", "linear", "rmst", "hazard", "cumhaz", "invlink(link)",
     "response", "link", "response", "prob", "count", "zero", "response",
     "response", "response", "link", "invlink(link)", "response",
     "link", "response", "link", "lp", "response", "link", "invlink(link)",
@@ -201,10 +202,11 @@
     "expected", "detection", "latent_N", "invlink(link)", "response",
     "link", "lp", "probability", "utility", "fitted", "mean", "lp",
     "probs", "response", "link", "lp", "mean", "probs", "response",
-    "link", "response", "response", "link", "unconditional", "response",
-    "response", "link", "response", "link", "response", "link", "quantile",
-    "response", "link", "probs", "response", "link", "expvalue",
-    "linpred", "prob", "response", "prob", "count", "zero"
+    "link", "response", "response", "link", "unconditional", "conditional",
+    "response", "response", "link", "response", "link", "response",
+    "link", "quantile", "response", "link", "probs", "response",
+    "link", "expvalue", "linpred", "prob", "response", "prob", "count",
+    "zero"
   ),
   stringsAsFactors = FALSE
 )
