@@ -61,7 +61,9 @@
     # we wouldn't expect that there is more than one of these columns, but we
     # check for that anyway...
     if (length(valid_y_vars) == 0) {
-      insight::format_error("Could not find a suitable column for the y-axis. Expected one of: 'Slope', 'Median', 'Mean', 'MAP'.")
+      insight::format_error(
+        "Could not find a suitable column for the y-axis. Expected one of: 'Slope', 'Median', 'Mean', 'MAP'."
+      )
     }
     aes$y <- valid_y_vars[1]
     if ("Comparison" %in% names(data)) {
@@ -119,7 +121,12 @@
       }
       # Append the component name if needed (e.g., "Subject: Days (sigma)")
       if ("Component" %in% facet_by) {
-        data$facet <- paste0(data$facet, " (", gsub("_", " ", data$Component, fixed = TRUE), ")")
+        data$facet <- paste0(
+          data$facet,
+          " (",
+          gsub("_", " ", data$Component, fixed = TRUE),
+          ")"
+        )
       }
       # Tell the main plotting function to use this new column for faceting
       aes$facet <- "facet"
@@ -135,7 +142,9 @@
     by <- att$by
   }
   if (length(by) == 0) {
-    insight::format_error("No `by` variable was detected, so nothing to put in the x-axis.")
+    insight::format_error(
+      "No `by` variable was detected, so nothing to put in the x-axis."
+    )
   }
 
   # first variable for x-axis - decide whether we have a dot- or a line-plot
@@ -181,7 +190,10 @@
     if (is.numeric(data[[by[3]]])) {
       aes$alpha <- by[3]
     } else {
-      aes$facet <- stats::as.formula(paste("~", paste(utils::tail(by, -2), collapse = " * ")))
+      aes$facet <- stats::as.formula(paste(
+        "~",
+        paste(utils::tail(by, -2), collapse = " * ")
+      ))
     }
     data$.group <- paste(data$.group, data[[by[3]]])
   }
@@ -255,20 +267,22 @@
 
 # Workhorse function ------------------------------------------------------
 
-
 #' @keywords internal
-.visualization_recipe <- function(x,
-                                  show_data = TRUE,
-                                  show_residuals = FALSE,
-                                  point = NULL,
-                                  line = NULL,
-                                  pointrange = NULL,
-                                  ribbon = NULL,
-                                  facet = NULL,
-                                  grid = NULL,
-                                  join_dots = TRUE,
-                                  numeric_as_discrete = 8,
-                                  ...) {
+.visualization_recipe <- function(
+  x,
+  show_data = TRUE,
+  show_residuals = FALSE,
+  collapse_by = NULL,
+  point = NULL,
+  line = NULL,
+  pointrange = NULL,
+  ribbon = NULL,
+  facet = NULL,
+  grid = NULL,
+  join_dots = TRUE,
+  numeric_as_discrete = 8,
+  ...
+) {
   # init
   response_scale <- attributes(x)$predict
   model_info <- attributes(x)$model_info
@@ -289,7 +303,10 @@
   }
 
   # Don't plot raw data if `predict` is not on the response scale
-  if (!is.null(response_scale) && !response_scale %in% c("prediction", "response", "expectation", "invlink(link)")) {
+  if (
+    !is.null(response_scale) &&
+      !response_scale %in% c("prediction", "response", "expectation", "invlink(link)")
+  ) {
     show_data <- show_residuals <- FALSE
   }
 
@@ -305,7 +322,7 @@
   }
 
   # add raw data as first layer ----------------------------------
-  if (show_data) {
+  if (show_data && is.null(collapse_by)) {
     layers[[paste0("l", l)]] <- .visualization_recipe_rawdata(x, aes, numeric_as_discrete)
     # Update with additional args
     if (!is.null(point)) {
@@ -314,10 +331,29 @@
     l <- l + 1
   }
 
-
   # add residual data as next lowest layer
-  if (show_residuals) {
-    layers[[paste0("l", l)]] <- .visualization_recipe_residuals(x, aes, numeric_as_discrete)
+  if (show_residuals && is.null(collapse_by)) {
+    layers[[paste0("l", l)]] <- .visualization_recipe_residuals(
+      x,
+      aes,
+      numeric_as_discrete
+    )
+    # Update with additional args
+    if (!is.null(point)) {
+      layers[[paste0("l", l)]] <- utils::modifyList(layers[[paste0("l", l)]], point)
+    }
+    l <- l + 1
+  }
+
+  # next possible data layer is collapsing by group ---------------
+  if (!is.null(collapse_by) && (show_data || show_residuals)) {
+    layers[[paste0("l", l)]] <- .visualization_recipe_collapsed_data(
+      x,
+      aes,
+      collapse_by,
+      numeric_as_discrete,
+      show_residuals
+    )
     # Update with additional args
     if (!is.null(point)) {
       layers[[paste0("l", l)]] <- utils::modifyList(layers[[paste0("l", l)]], point)
@@ -337,7 +373,6 @@
     global_aes$group <- ".group"
   }
 
-
   # Uncertainty -----------------------------------
   if (!identical(ribbon, "none") && aes$type == "ribbon" && is.null(aes$alpha)) {
     for (i in seq_along(aes$ymin)) {
@@ -371,21 +406,12 @@
   # connecting lines between point geoms
   if (!aes$type %in% do_not_join) {
     # base list elements
-    aes_list <- list(
-      y = aes$y,
-      x = aes$x,
-      color = aes$color,
-      alpha = aes$alpha
-    )
+    aes_list <- list(y = aes$y, x = aes$x, color = aes$color, alpha = aes$alpha)
     # optionally add group aes, if not in global_aes and not null
     if (!"group" %in% names(global_aes) || !is.null(aes$group)) {
       aes_list$group <- aes$group
     }
-    layers[[paste0("l", l)]] <- list(
-      geom = "line",
-      data = data,
-      aes = aes_list
-    )
+    layers[[paste0("l", l)]] <- list(geom = "line", data = data, aes = aes_list)
     if (!is.null(aes$color) && aes$type %in% c("pointrange", "point")) {
       layers[[paste0("l", l)]]$position <- "dodge"
       layers[[paste0("l", l)]]$width <- 0.2
@@ -425,14 +451,9 @@
     l <- l + 1
   }
 
-
   # grids and facets ----------------------------------
   if (!is.null(aes$facet)) {
-    layers[[paste0("l", l)]] <- list(
-      geom = "facet_wrap",
-      data = data,
-      facets = aes$facet
-    )
+    layers[[paste0("l", l)]] <- list(geom = "facet_wrap", data = data, facets = aes$facet)
     if (!is.null(facet)) {
       layers[[paste0("l", l)]] <- utils::modifyList(layers[[paste0("l", l)]], facet)
     }
@@ -451,7 +472,6 @@
     l <- l + 1
   }
 
-
   # add axis and legend labels ----------------------------------
   if (!is.null(aes$labs)) {
     layers[[paste0("l", l)]] <- insight::compact_list(list(
@@ -464,11 +484,11 @@
     l <- l + 1
   }
 
-
   # probability scale? ----------------------------------
   if (
     !is.null(response_scale) &&
-      response_scale %in% c("response", "expectation", "invlink(link)", "prob", "probs") &&
+      response_scale %in%
+        c("response", "expectation", "invlink(link)", "prob", "probs") &&
       isTRUE(
         model_info$is_logit |
           model_info$is_binomial |
@@ -491,9 +511,12 @@
     l <- l + 1
   }
 
-
   # Out
-  class(layers) <- unique(c("visualisation_recipe", "see_visualisation_recipe", class(layers)))
+  class(layers) <- unique(c(
+    "visualisation_recipe",
+    "see_visualisation_recipe",
+    class(layers)
+  ))
   attr(layers, "data") <- data
   attr(layers, "global_aes") <- insight::compact_list(global_aes)
   layers
@@ -502,10 +525,9 @@
 
 # Raw data ----------------------------------------------------------------
 
-
 #' @keywords internal
 .visualization_recipe_rawdata <- function(x, aes, numeric_as_discrete = 8) {
-  model <- attributes(x)$model
+  model <- insight::get_model(x)
   rawdata <- insight::get_data(model, verbose = FALSE)
 
   # Add response to data if not there
@@ -518,35 +540,46 @@
   # is used by default - we then must convert values into factors, when we
   # show data or residuals - but we must ensure that the levels are sorted
   # according to the original data grid, thus we need "sort()"
-  if (!is.null(aes$color) && is.numeric(rawdata[[aes$color]]) && insight::n_unique(rawdata[[aes$color]]) < numeric_as_discrete) {
+  if (
+    !is.null(aes$color) &&
+      is.numeric(rawdata[[aes$color]]) &&
+      insight::n_unique(rawdata[[aes$color]]) < numeric_as_discrete
+  ) {
     new_values <- insight::format_value(rawdata[[aes$color]], protect_integers = TRUE)
-    rawdata[[aes$color]] <- factor(new_values, levels = as.character(sort(as.numeric(unique(new_values)))))
+    rawdata[[aes$color]] <- factor(
+      new_values,
+      levels = as.character(sort(as.numeric(unique(new_values))))
+    )
   }
 
-  .data_point_geom(
-    model = model,
-    aes = aes,
-    data = rawdata,
-    y = y
-  )
+  .data_point_geom(model = model, aes = aes, data = rawdata, y = y)
 }
 
 
 # residuals ----------------------------------------------------------------
 
-
 #' @keywords internal
 .visualization_recipe_residuals <- function(x, aes, numeric_as_discrete = 8) {
-  model <- attributes(x)$model
+  model <- insight::get_model(x)
   residual_data <- residualize_over_grid(x, model)
 
   # if we have less than 8 values for the legend, a continuous color scale
   # is used by default - we then must convert values into factors, when we
   # show data or residuals - but we must ensure that the levels are sorted
   # according to the original data grid, thus we need "sort()"
-  if (!is.null(aes$color) && is.numeric(residual_data[[aes$color]]) && insight::n_unique(residual_data[[aes$color]]) < numeric_as_discrete) {
-    new_values <- insight::format_value(residual_data[[aes$color]], protect_integers = TRUE)
-    residual_data[[aes$color]] <- factor(new_values, levels = as.character(sort(as.numeric(unique(new_values)))))
+  if (
+    !is.null(aes$color) &&
+      is.numeric(residual_data[[aes$color]]) &&
+      insight::n_unique(residual_data[[aes$color]]) < numeric_as_discrete
+  ) {
+    new_values <- insight::format_value(
+      residual_data[[aes$color]],
+      protect_integers = TRUE
+    )
+    residual_data[[aes$color]] <- factor(
+      new_values,
+      levels = as.character(sort(as.numeric(unique(new_values))))
+    )
   }
 
   .data_point_geom(
@@ -558,9 +591,49 @@
 }
 
 
+# Collapsed data ----------------------------------------------------------------
+
+#' @keywords internal
+.visualization_recipe_collapsed_data <- function(
+  x,
+  aes,
+  collapse_by,
+  numeric_as_discrete = 8,
+  show_residuals = FALSE
+) {
+  model <- insight::get_model(x)
+  rawdata <- collapse_by_group(x, model, collapse_by, residuals = show_residuals)
+
+  # if we have less than 8 values for the legend, a continuous color scale
+  # is used by default - we then must convert values into factors, when we
+  # show data or residuals - but we must ensure that the levels are sorted
+  # according to the original data grid, thus we need "sort()"
+  if (
+    !is.null(aes$color) &&
+      is.numeric(rawdata[[aes$color]]) &&
+      insight::n_unique(rawdata[[aes$color]]) < numeric_as_discrete
+  ) {
+    new_values <- insight::format_value(rawdata[[aes$color]], protect_integers = TRUE)
+    rawdata[[aes$color]] <- factor(
+      new_values,
+      levels = as.character(sort(as.numeric(unique(new_values))))
+    )
+  }
+
+  .data_point_geom(
+    model = model,
+    aes = aes,
+    data = rawdata,
+    y = insight::find_response(model),
+    size = 2,
+    jitter = 0.1
+  )
+}
+
+
 # helpers -----------------------------------------------------------------
 
-.data_point_geom <- function(model, aes, data, y) {
+.data_point_geom <- function(model, aes, data, y, ...) {
   if (aes$type == "pointrange" && !is.numeric(data[[aes$x]])) {
     geom <- "jitter"
   } else {
@@ -578,17 +651,21 @@
   out <- list(
     geom = geom,
     data = data,
-    aes = list(
-      y = y,
-      x = aes$x,
-      color = aes$color,
-      alpha = aes$alpha
-    ),
+    aes = list(y = y, x = aes$x, color = aes$color, alpha = aes$alpha),
     height = 0,
     shape = shape,
     stroke = stroke
   )
 
+  dots <- list(...)
+  if (!is.null(dots$size)) {
+    out$size <- dots$size
+  }
+  if (!is.null(dots$jitter)) {
+    out$position <- "jitter"
+    out$width <- dots$jitter
+  }
+
   # check if we have matching columns in the raw data - some functions,
   # likes slopes, have mapped these aes to other columns that are not part
   # of the raw data - we set them to NULL
