@@ -2,6 +2,7 @@ skip_on_cran()
 skip_if_not_installed("marginaleffects", minimum_version = "0.29.0")
 skip_if_not_installed("nanoparquet")
 skip_if_not_installed("sandwich")
+skip_if_not_installed("Rdatasets")
 skip_on_os("mac")
 
 test_that("estimate_contrasts - vcov", {
@@ -10,13 +11,26 @@ test_that("estimate_contrasts - vcov", {
   dat$win_big <- as.factor(dat$win_big)
 
   mod <- lm(
-    earnings_post_avg ~ win_big * (
-      tickets + man + work + age + education + college + year +
-        earnings_pre_1 + earnings_pre_2 + earnings_pre_3),
+    earnings_post_avg ~ win_big *
+      (tickets +
+        man +
+        work +
+        age +
+        education +
+        college +
+        year +
+        earnings_pre_1 +
+        earnings_pre_2 +
+        earnings_pre_3),
     data = dat
   )
 
-  out1 <- marginaleffects::avg_predictions(mod, variables = "win_big", by = "win_big", vcov = "HC3")
+  out1 <- marginaleffects::avg_predictions(
+    mod,
+    variables = "win_big",
+    by = "win_big",
+    vcov = "HC3"
+  )
   out2 <- estimate_means(mod, "win_big", vcov = "HC3")
   expect_equal(out1$std.error, out2$SE, tolerance = 1e-4)
 })
